@@ -1,19 +1,24 @@
 #  Copyright (c) Kuba Szczodrzyński 2023-1-7.
 
 from .helper import (
+    bitfield,
     buffer_end,
     buffer_start,
     checksum_end,
     checksum_field,
     checksum_start,
+    const_into,
+    eval_into,
     hook_end,
     packing,
     probe,
+    tell,
+    tell_into,
     unpacking,
     validate,
     virtual,
 )
-from .special import action, align, hook, padding, seek, skip
+from .special import action, align, alignto, hook, padding, seek, skip
 from .standard import built, field, subfield
 from .wrapper import adapter, cond, repeat, switch
 
@@ -21,6 +26,8 @@ __all__ = [
     "action",
     "adapter",
     "align",
+    "alignto",
+    "bitfield",
     "buffer_end",
     "buffer_start",
     "built",
@@ -28,6 +35,8 @@ __all__ = [
     "checksum_field",
     "checksum_start",
     "cond",
+    "const_into",
+    "eval_into",
     "field",
     "hook",
     "hook_end",
@@ -39,6 +48,8 @@ __all__ = [
     "skip",
     "subfield",
     "switch",
+    "tell",
+    "tell_into",
     "unpacking",
     "validate",
     "virtual",
